@@ -57,10 +57,12 @@ class TestSMW(BaseSemanticMediawikiTest):
         for target_key in ["category","concept","form","help","listOf","template","properties"]:
             smwTarget=SMWTarget.getSMWTargets()[target_key]
             ypCell=YpCell.createYpCell(target=smwTarget,topic=topic,debug=debug)
-            markup_diff=ypCell.generate(smwAccess=smwAccess,dryRun=True,withEditor=withEditor)
-            if markup_diff:
-                diff_lines=markup_diff.split("\n")
-                print(f"""found {len(diff_lines)} line differences for {ypCell.getPageTitle()}""")
-                if self.debug:
-                    print(markup_diff)       
+            genResult=ypCell.generateViaMwApi(smwAccess=smwAccess,dryRun=True,withEditor=withEditor)
+            if genResult:
+                markup_diff=genResult.markup_diff
+                if markup_diff:
+                    diff_lines=markup_diff.split("\n")
+                    print(f"""found {len(diff_lines)} line differences for {ypCell.getPageTitle()}""")
+                    if self.debug:
+                        print(markup_diff)       
                 
\ No newline at end of file
